[HIPIFY][fix][#1109] Do not preserve extern __shared__ for IncompleteArrayType

+ Update tests accordingly


[ROCm/hip commit: fa3dda9107]
Dieser Commit ist enthalten in:
Evgeny Mankov
2019-05-15 20:05:56 +03:00
Ursprung ea09ce30c5
Commit 2472ece71d
3 geänderte Dateien mit 4 neuen und 1 gelöschten Zeilen
@@ -352,7 +352,7 @@ bool HipifyAction::cudaSharedIncompleteArrayVar(const clang::ast_matchers::Match
}
if (!typeName.empty()) {
clang::SourceLocation slStart = llcompat::getBeginLoc(sharedVar->getTypeSourceInfo()->getTypeLoc());
clang::SourceLocation slStart = sharedVar->getOuterLocStart();
clang::SourceLocation slEnd = llcompat::getEndLoc(sharedVar->getTypeSourceInfo()->getTypeLoc());
clang::SourceManager* SM = Result.SourceManager;
size_t repLength = SM->getCharacterData(slEnd) - SM->getCharacterData(slStart) + 1;
@@ -9,6 +9,7 @@
__global__ void dynamicReverse(int *d, int n)
{
// Dynamic shared memory
// CHECK-NOT: extern __shared__
// CHECK: HIP_DYNAMIC_SHARED(int, s);
extern __shared__ int s[];
int t = threadIdx.x;
@@ -8,6 +8,8 @@
__global__ void staticReverse(int *d, int n)
{
// CHECK-NOT: HIP_DYNAMIC_SHARED(int, s);
// CHECK: __shared__ int s[64];
__shared__ int s[64];
int t = threadIdx.x;
int tr = n-t-1;